Learn R Programming

stylest2 (version 0.1)

stylest: stylest2: A package for estimating authorship of texts.

Description

stylest2 provides a set of functions for fitting a model of speaker distinctiveness, including tools for selecting the optimal vocabulary for the model and predicting the most likely speaker (author) of a new text.

Arguments