Internal stylest2 function to predict log odds of speakership across texts.
speaker_odds(log_weights, pred_docs_dfm, pred_docs_ntoken, speakers)The logged author-level term weights from a stylest2 model.
A document-feature matrix for the texts to be predicted.
A vector, the number of tokens in each prediction document.
The speaker labels for pred_docs_dfm rows.